# Rustic AI Redis

This module provides a [Redis](https://redis.io/software/) based implementations of [Rustic AI](https://www.rustic.ai/)'s messaging backend, key value store, etc.

## Installing

```shell
pip install rusticai-redis
```
**Note:** It depends on [rusticai-core](https://pypi.org/project/rusticai-core/)

## Building from Source

```shell
poetry install --with dev
poetry build
```